Improve this Doc

# Error: $http:badreq
Bad Request Configuration

    Http request configuration url must be a string or a $sce trusted object.  Received: {0}

## Description

This error occurs when the request configuration parameter passed to the `$http` service is not a valid object. `$http` expects a single parameter, the request configuration object, but received a parameter that was not an object or did not contain valid properties.

The error message should provide additional context such as the actual value of the parameter that was received. If you passed a string parameter, perhaps you meant to call one of the shorthand methods on `$http` such as `$http.get(…)`, etc.

To resolve this error, make sure you pass a valid request configuration object to `$http`.

For more information, see the `$http` service API documentation.